# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.severity_enum import SeverityEnum

class TestSeverityEnum(unittest.TestCase):
    """SeverityEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSeverityEnum(self):
        """Test SeverityEnum"""
        # inst = SeverityEnum()

if __name__ == '__main__':
    unittest.main()
